package de.szut.lf8_starter.employee;

import de.szut.lf8_starter.exceptionHandling.ResourceNotFoundException;
import de.szut.lf8_starter.project.dto.employee.GetEmployeeDto;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.stereotype.Service;
import org.springframework.web.client.HttpClientErrorException;
import org.springframework.web.client.RestTemplate;

@Service
public class EmployeeService {
    private final RestTemplate restTemplate;

    public EmployeeService(RestTemplate restTemplate) {
        this.restTemplate = restTemplate;
    }

    public boolean employeeExists(String accessToken, Long employeeId) {
        HttpHeaders headers = new HttpHeaders();
        headers.setBearerAuth(accessToken.replace("Bearer ", ""));

        HttpEntity<String> requestEntity = new HttpEntity<>(headers);

        String url = "https://employee.szut.dev/employees/" + employeeId;

        try {
            restTemplate.exchange(url, HttpMethod.GET, requestEntity, String.class);
        } catch (HttpClientErrorException.NotFound e) {
            return false;
        }

        return true;
    }

    public GetEmployeeDto getEmployee(String accessToken, Long employeeId) {
        HttpHeaders headers = new HttpHeaders();
        headers.setBearerAuth(accessToken.replace("Bearer ", ""));

        HttpEntity<String> requestEntity = new HttpEntity<>(headers);

        String url = "https://employee.szut.dev/employees/" + employeeId;

        try {
            return restTemplate.exchange(url, HttpMethod.GET, requestEntity, GetEmployeeDto.class).getBody();
        } catch (HttpClientErrorException.NotFound e) {
            throw new ResourceNotFoundException("Employee not found");
        }
    }
}
