package de.szut.lf8_starter.project.action.crud;

import de.szut.lf8_starter.project.ProjectService;
import de.szut.lf8_starter.project.dto.project.GetProjectDto;
import de.szut.lf8_starter.project.mapper.ProjectMapper;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.media.Content;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.responses.ApiResponses;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@RestController
@RequestMapping(value = "projects")
public class GetAllProjectsAction {
    private final ProjectService service;
    private final ProjectMapper projectMapper;

    public GetAllProjectsAction(ProjectService service, ProjectMapper projectMapper) {
        this.service = service;
        this.projectMapper = projectMapper;
    }

    @Operation(summary = "returns all projects")
    @ApiResponses(value = {
            @ApiResponse(responseCode = "200", description = "all projects", content = {
                    @Content(mediaType = "application/json", schema = @Schema(implementation = GetProjectDto.class))
            }),
            @ApiResponse(responseCode = "401", description = "not authorized", content = @Content)})
    @GetMapping
    public List<GetProjectDto> findAll() {
        return this.service
                .readAll()
                .stream()
                .map(this.projectMapper::mapToGetDto)
                .toList();
    }
}
