package de.szut.lf8_starter.project.action.employee;

import de.szut.lf8_starter.project.ProjectEntity;
import de.szut.lf8_starter.project.ProjectService;
import de.szut.lf8_starter.project.dto.employee.GetEmployeesFromProjectDto;
import de.szut.lf8_starter.project.mapper.EmployeeFromProjectMapper;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.media.Content;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.responses.ApiResponses;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RestController;

import java.util.Optional;

@RestController
public class GetEmployeeFromProjectAction {
    private final ProjectService projectService;
    private final EmployeeFromProjectMapper employeeFromProjectMapper;

    public GetEmployeeFromProjectAction(ProjectService projectService, EmployeeFromProjectMapper employeeFromProjectMapper) {
        this.projectService = projectService;
        this.employeeFromProjectMapper = employeeFromProjectMapper;
    }

    @Operation(summary = "Get all employees from project")
    @ApiResponses(value = {
            @ApiResponse(responseCode = "200", description = "Outputs projects with employees"),
            @ApiResponse(responseCode = "404", description = "Project not found", content = @Content)
    })
    @GetMapping("/projects/{projectId}/employees")
    public ResponseEntity<Object> create(
            @PathVariable Long projectId,
            @RequestHeader("Authorization") String accessToken
    ) {
        Optional<ProjectEntity> project = projectService.findById(projectId);

        if (project.isEmpty()) {
            return new ResponseEntity<>(HttpStatus.NOT_FOUND);
        }

        GetEmployeesFromProjectDto getEmployeesFromProjectDto = this.employeeFromProjectMapper
                .mapToGetEmployeesFromProjectDto(project.get(), accessToken);

        return new ResponseEntity<>(getEmployeesFromProjectDto, HttpStatus.OK);
    }
}
